@@ -14,8 +14,7 @@ class AndroidRecipe(IncludedFilesBehaviour, CythonRecipe):
 
     src_filename = 'src'
 
-    depends = [('pygame', 'sdl2', 'genericndkbuild'),
-               'pyjnius']
+    depends = [('sdl2', 'genericndkbuild'), 'pyjnius']
 
     config_env = {}
 
@@ -39,17 +38,14 @@ class AndroidRecipe(IncludedFilesBehaviour, CythonRecipe):
         bootstrap = bootstrap_name = ctx_bootstrap
 
         is_sdl2 = bootstrap_name in ('sdl2', 'sdl2python3', 'sdl2_gradle')
-        is_pygame = bootstrap_name in ('pygame',)
-        is_webview = bootstrap_name in ('webview',)
+        is_webview = bootstrap_name == 'webview'
+        is_service_only = bootstrap_name == 'service_only'
 
-        if is_sdl2 or is_webview:
+        if is_sdl2 or is_webview or is_service_only:
             if is_sdl2:
                 bootstrap = 'sdl2'
-            java_ns = 'org.kivy.android'
-            jni_ns = 'org/kivy/android'
-        elif is_pygame:
-            java_ns = b'org.renpy.android'
-            jni_ns = b'org/renpy/android'
+            java_ns = u'org.kivy.android'
+            jni_ns = u'org/kivy/android'
         else:
             logger.error((
                 'unsupported bootstrap for android recipe: {}'
@@ -60,7 +56,6 @@ class AndroidRecipe(IncludedFilesBehaviour, CythonRecipe):
         config = {
             'BOOTSTRAP': bootstrap,
             'IS_SDL2': int(is_sdl2),
-            'IS_PYGAME': int(is_pygame),
             'PY2': int(will_build('python2')(self)),
             'JAVA_NAMESPACE': java_ns,
             'JNI_NAMESPACE': jni_ns,
@@ -88,8 +83,6 @@ class AndroidRecipe(IncludedFilesBehaviour, CythonRecipe):
                 fh.write(
                     '#define SDL_ANDROID_GetJNIEnv SDL_AndroidGetJNIEnv\n'
                 )
-            elif is_pygame:
-                fh.write('JNIEnv *SDL_ANDROID_GetJNIEnv(void);\n')
 
 
 recipe = AndroidRecipe()
