@@ -2,9 +2,10 @@ from pythonforandroid.toolchain import Recipe
 
 
 class FFPyPlayerCodecsRecipe(Recipe):
-    depends = ['libshine', 'libx264']
+    depends = ['libx264', 'libshine']
 
     def build_arch(self, arch):
         pass
 
+
 recipe = FFPyPlayerCodecsRecipe()
