@@ -6,7 +6,7 @@ import os.path
 class LibpqRecipe(Recipe):
     version = '9.5.3'
     url = 'http://ftp.postgresql.org/pub/source/v{version}/postgresql-{version}.tar.bz2'
-    depends = [('python2', 'python3crystax')]
+    depends = []
 
     def should_build(self, arch):
         return not os.path.isfile('{}/libpq.a'.format(self.ctx.get_libs_dir(arch.arch)))
@@ -22,4 +22,5 @@ class LibpqRecipe(Recipe):
             shprint(sh.cp, '-a', 'src/interfaces/libpq/libpq.a',
                     self.ctx.get_libs_dir(arch.arch))
 
+
 recipe = LibpqRecipe()
